==> ocaml-merlin_4.13-414+ds.orig.tar.xz: merlin-4.13-414/src/utils/file_cache.mli <==
(* {{{ COPYING *(

  This file is part of Merlin, an helper for ocaml editors

  Copyright (C) 2013 - 2015  Frédéric Bour  <frederic.bour(_)lakaban.net>
                             Thomas Refis  <refis.thomas(_)gmail.com>
                             Simon Castellan  <simon.castellan(_)iuwt.fr>

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  The Software is provided "as is", without warranty of any kind, express or
  implied, including but not limited to the warranties of merchantability,
  fitness for a particular purpose and noninfringement. In no event shall
  the authors or copyright holders be liable for any claim, damages or other
  liability, whether in an action of contract, tort or otherwise, arising
  from, out of or in connection with the software or the use or other dealings
  in the Software.

)* }}} *)

module Make (Input : sig
  type t
  val read : string -> t
  val cache_name : string
end) : sig
  val read  : string -> Input.t
  val flush : ?older_than:float -> unit -> unit
  val clear : unit -> unit
  val check : string -> bool

  val get_cached_entry : string -> Input.t
  (** @raises Not_found if the file is not in cache. *)
end

==> ocaml-merlin_5.1-502+ds.orig.tar.xz: merlin-5.1-502/src/utils/file_cache.mli <==
(* {{{ COPYING *(

  This file is part of Merlin, an helper for ocaml editors

  Copyright (C) 2013 - 2015  Frédéric Bour  <frederic.bour(_)lakaban.net>
                             Thomas Refis  <refis.thomas(_)gmail.com>
                             Simon Castellan  <simon.castellan(_)iuwt.fr>

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  The Software is provided "as is", without warranty of any kind, express or
  implied, including but not limited to the warranties of merchantability,
  fitness for a particular purpose and noninfringement. In no event shall
  the authors or copyright holders be liable for any claim, damages or other
  liability, whether in an action of contract, tort or otherwise, arising
  from, out of or in connection with the software or the use or other dealings
  in the Software.

)* }}} *)

module Make (Input : sig
  type t
  val read : string -> t
  val cache_name : string
end) : sig
  val read  : string -> Input.t
  val flush : ?older_than:float -> unit -> unit
  val clear : unit -> unit
  val check : string -> bool

  val get_cached_entry : string -> Input.t
  (** @raises Not_found if the file is not in cache. *)

  type cache_stats = { hit: int; miss: int }
  val get_cache_stats : unit -> cache_stats
  val clear_cache_stats : unit -> unit
end
